# valis-hest

Modified version of Valis used in HEST. Please visit the original Valis repo for more information https://github.com/MathOnco/valis


`valis-hest` is a lightweight version of Valis and might not include all valis features.
`valid-hest` also fixes some alignment issues encountered with the official Valis release when aligning the HEST-1k datasets.